# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcsdk_gcmessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import dota2.protobufs.steammessages_pb2 as steammessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gcsdk_gcmessages.proto',
  package='dota',
  syntax='proto2',
  serialized_options=_b('H\001\220\001\000'),
  serialized_pb=_b('\n\x16gcsdk_gcmessages.proto\x12\x04\x64ota\x1a\x13steammessages.proto\"@\n\x0e\x43MsgSHA1Digest\x12\x0e\n\x06\x62lock1\x18\x01 \x02(\x06\x12\x0e\n\x06\x62lock2\x18\x02 \x02(\x06\x12\x0e\n\x06\x62lock3\x18\x03 \x02(\x07\")\n\rCMsgSOIDOwner\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\n\n\x02id\x18\x02 \x01(\x04\"\x88\x01\n\x12\x43MsgSOSingleObject\x12\x0f\n\x07type_id\x18\x02 \x01(\x05\x12\x13\n\x0bobject_data\x18\x03 \x01(\x0c\x12\x0f\n\x07version\x18\x04 \x01(\x06\x12\'\n\nowner_soid\x18\x05 \x01(\x0b\x32\x13.dota.CMsgSOIDOwner\x12\x12\n\nservice_id\x18\x06 \x01(\r\"\xef\x02\n\x15\x43MsgSOMultipleObjects\x12\x42\n\x10objects_modified\x18\x02 \x03(\x0b\x32(.dota.CMsgSOMultipleObjects.SingleObject\x12\x0f\n\x07version\x18\x03 \x01(\x06\x12?\n\robjects_added\x18\x04 \x03(\x0b\x32(.dota.CMsgSOMultipleObjects.SingleObject\x12\x41\n\x0fobjects_removed\x18\x05 \x03(\x0b\x32(.dota.CMsgSOMultipleObjects.SingleObject\x12\'\n\nowner_soid\x18\x06 \x01(\x0b\x32\x13.dota.CMsgSOIDOwner\x12\x12\n\nservice_id\x18\x07 \x01(\r\x1a@\n\x0cSingleObject\x12\x0f\n\x07type_id\x18\x01 \x01(\x05\x12\x13\n\x0bobject_data\x18\x02 \x01(\x0c:\n\x80\x97\"\x80\x02\x88\x97\"\x80\x08\"\x86\x02\n\x15\x43MsgSOCacheSubscribed\x12;\n\x07objects\x18\x02 \x03(\x0b\x32*.dota.CMsgSOCacheSubscribed.SubscribedType\x12\x0f\n\x07version\x18\x03 \x01(\x06\x12\'\n\nowner_soid\x18\x04 \x01(\x0b\x32\x13.dota.CMsgSOIDOwner\x12\x12\n\nservice_id\x18\x05 \x01(\r\x12\x14\n\x0cservice_list\x18\x06 \x03(\r\x12\x14\n\x0csync_version\x18\x07 \x01(\x06\x1a\x36\n\x0eSubscribedType\x12\x0f\n\x07type_id\x18\x01 \x01(\x05\x12\x13\n\x0bobject_data\x18\x02 \x03(\x0c\"\x99\x01\n\x1d\x43MsgSOCacheSubscribedUpToDate\x12\x0f\n\x07version\x18\x01 \x01(\x06\x12\'\n\nowner_soid\x18\x02 \x01(\x0b\x32\x13.dota.CMsgSOIDOwner\x12\x12\n\nservice_id\x18\x03 \x01(\r\x12\x14\n\x0cservice_list\x18\x04 \x03(\r\x12\x14\n\x0csync_version\x18\x05 \x01(\x06\"B\n\x17\x43MsgSOCacheUnsubscribed\x12\'\n\nowner_soid\x18\x02 \x01(\x0b\x32\x13.dota.CMsgSOIDOwner\"\x98\x01\n\x1c\x43MsgSOCacheSubscriptionCheck\x12\x0f\n\x07version\x18\x02 \x01(\x06\x12\'\n\nowner_soid\x18\x03 \x01(\x0b\x32\x13.dota.CMsgSOIDOwner\x12\x12\n\nservice_id\x18\x04 \x01(\r\x12\x14\n\x0cservice_list\x18\x05 \x03(\r\x12\x14\n\x0csync_version\x18\x06 \x01(\x06\"I\n\x1e\x43MsgSOCacheSubscriptionRefresh\x12\'\n\nowner_soid\x18\x02 \x01(\x0b\x32\x13.dota.CMsgSOIDOwner\"%\n\x12\x43MsgSOCacheVersion\x12\x0f\n\x07version\x18\x01 \x01(\x06\"L\n\x16\x43MsgGCMultiplexMessage\x12\x0f\n\x07msgtype\x18\x01 \x01(\r\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x12\x10\n\x08steamids\x18\x03 \x03(\x06\",\n\x17\x43MsgGCToGCSubGCStarting\x12\x11\n\tdir_index\x18\x01 \x01(\r\"\xc0\x01\n\x13\x43GCToGCMsgMasterAck\x12\x11\n\tdir_index\x18\x01 \x01(\r\x12\x14\n\x0cmachine_name\x18\x03 \x01(\t\x12\x14\n\x0cprocess_name\x18\x04 \x01(\t\x12\x34\n\tdirectory\x18\x06 \x03(\x0b\x32!.dota.CGCToGCMsgMasterAck.Process\x1a\x34\n\x07Process\x12\x11\n\tdir_index\x18\x01 \x01(\r\x12\x16\n\x0etype_instances\x18\x02 \x03(\r\"2\n\x1c\x43GCToGCMsgMasterAck_Response\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\"7\n\x19\x43MsgGCToGCUniverseStartup\x12\x1a\n\x12is_initial_startup\x18\x01 \x01(\x08\"4\n!CMsgGCToGCUniverseStartupResponse\x12\x0f\n\x07\x65result\x18\x01 \x01(\x05\"\x93\x01\n\x1f\x43GCToGCMsgMasterStartupComplete\x12=\n\x07gc_info\x18\x01 \x03(\x0b\x32,.dota.CGCToGCMsgMasterStartupComplete.GCInfo\x1a\x31\n\x06GCInfo\x12\x11\n\tdir_index\x18\x01 \x01(\r\x12\x14\n\x0cmachine_name\x18\x02 \x01(\t\"L\n\x10\x43GCToGCMsgRouted\x12\x10\n\x08msg_type\x18\x01 \x01(\r\x12\x11\n\tsender_id\x18\x02 \x01(\x06\x12\x13\n\x0bnet_message\x18\x03 \x01(\x0c\">\n\x15\x43GCToGCMsgRoutedReply\x12\x10\n\x08msg_type\x18\x01 \x01(\r\x12\x13\n\x0bnet_message\x18\x02 \x01(\x0c\"\x9a\x01\n\x1c\x43MsgGCUpdateSubGCSessionInfo\x12>\n\x07updates\x18\x01 \x03(\x0b\x32-.dota.CMsgGCUpdateSubGCSessionInfo.CMsgUpdate\x1a:\n\nCMsgUpdate\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\n\n\x02ip\x18\x02 \x01(\x07\x12\x0f\n\x07trusted\x18\x03 \x01(\x08\"0\n\x1d\x43MsgGCRequestSubGCSessionInfo\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"c\n%CMsgGCRequestSubGCSessionInfoResponse\x12\n\n\x02ip\x18\x01 \x01(\x07\x12\x0f\n\x07trusted\x18\x02 \x01(\x08\x12\x0c\n\x04port\x18\x03 \x01(\r\x12\x0f\n\x07success\x18\x04 \x01(\x08\"}\n\x16\x43MsgSOCacheHaveVersion\x12!\n\x04soid\x18\x01 \x01(\x0b\x32\x13.dota.CMsgSOIDOwner\x12\x0f\n\x07version\x18\x02 \x01(\x06\x12\x12\n\nservice_id\x18\x03 \x01(\r\x12\x1b\n\x13\x63\x61\x63hed_file_version\x18\x04 \x01(\r\"\xe2\x02\n\x0f\x43MsgClientHello\x12\x0f\n\x07version\x18\x01 \x01(\r\x12;\n\x15socache_have_versions\x18\x02 \x03(\x0b\x32\x1c.dota.CMsgSOCacheHaveVersion\x12\x1b\n\x13\x63lient_session_need\x18\x03 \x01(\r\x12?\n\x0f\x63lient_launcher\x18\x04 \x01(\x0e\x32\x18.dota.PartnerAccountType:\x0cPARTNER_NONE\x12\x12\n\nsecret_key\x18\x05 \x01(\t\x12\x17\n\x0f\x63lient_language\x18\x06 \x01(\r\x12\x32\n\x06\x65ngine\x18\x07 \x01(\x0e\x32\x13.dota.ESourceEngine:\rk_ESE_Source1\x12\x1b\n\x13steamdatagram_login\x18\x08 \x01(\x0c\x12\x13\n\x0bplatform_id\x18\t \x01(\r\x12\x10\n\x08game_msg\x18\n \x01(\x0c\"\xba\x03\n\x11\x43MsgClientWelcome\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x11\n\tgame_data\x18\x02 \x01(\x0c\x12@\n\x1boutofdate_subscribed_caches\x18\x03 \x03(\x0b\x32\x1b.dota.CMsgSOCacheSubscribed\x12\x46\n\x1auptodate_subscribed_caches\x18\x04 \x03(\x0b\x32\".dota.CMsgSOCacheSubscriptionCheck\x12\x32\n\x08location\x18\x05 \x01(\x0b\x32 .dota.CMsgClientWelcome.Location\x12\x15\n\rsave_game_key\x18\x06 \x01(\x0c\x12\x17\n\x0fitem_schema_crc\x18\x07 \x01(\x07\x12\x16\n\x0eitems_game_url\x18\x08 \x01(\t\x12\x1f\n\x17gc_socache_file_version\x18\t \x01(\r\x12\x18\n\x10txn_country_code\x18\n \x01(\t\x1a@\n\x08Location\x12\x10\n\x08latitude\x18\x01 \x01(\x02\x12\x11\n\tlongitude\x18\x02 \x01(\x02\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\"\xea\x01\n\x14\x43MsgConnectionStatus\x12I\n\x06status\x18\x01 \x01(\x0e\x32\x18.dota.GCConnectionStatus:\x1fGCConnectionStatus_HAVE_SESSION\x12\x1b\n\x13\x63lient_session_need\x18\x02 \x01(\r\x12\x16\n\x0equeue_position\x18\x03 \x01(\x05\x12\x12\n\nqueue_size\x18\x04 \x01(\x05\x12\x14\n\x0cwait_seconds\x18\x05 \x01(\x05\x12(\n estimated_wait_seconds_remaining\x18\x06 \x01(\x05\"\xfd\x01\n\x1a\x43MsgGCToGCSOCacheSubscribe\x12\x12\n\nsubscriber\x18\x01 \x01(\x06\x12\x17\n\x0fsubscribe_to_id\x18\x02 \x01(\x06\x12\x14\n\x0csync_version\x18\x03 \x01(\x06\x12H\n\rhave_versions\x18\x04 \x03(\x0b\x32\x31.dota.CMsgGCToGCSOCacheSubscribe.CMsgHaveVersions\x12\x19\n\x11subscribe_to_type\x18\x05 \x01(\r\x1a\x37\n\x10\x43MsgHaveVersions\x12\x12\n\nservice_id\x18\x01 \x01(\r\x12\x0f\n\x07version\x18\x02 \x01(\x04\"n\n\x1c\x43MsgGCToGCSOCacheUnsubscribe\x12\x12\n\nsubscriber\x18\x01 \x01(\x06\x12\x1b\n\x13unsubscribe_from_id\x18\x02 \x01(\x06\x12\x1d\n\x15unsubscribe_from_type\x18\x03 \x01(\r\"\x12\n\x10\x43MsgGCClientPing\"\x8f\x01\n\x1f\x43MsgGCToGCForwardAccountDetails\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x46\n\x0f\x61\x63\x63ount_details\x18\x02 \x01(\x0b\x32-.dota.CGCSystemMsg_GetAccountDetails_Response\x12\x13\n\x0b\x61ge_seconds\x18\x03 \x01(\r\"z\n\x1c\x43MsgGCToGCLoadSessionSOCache\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x46\n\x17\x66orward_account_details\x18\x02 \x01(\x0b\x32%.dota.CMsgGCToGCForwardAccountDetails\"&\n$CMsgGCToGCLoadSessionSOCacheResponse\"f\n\x1c\x43MsgGCToGCUpdateSessionStats\x12\x15\n\ruser_sessions\x18\x01 \x01(\r\x12\x17\n\x0fserver_sessions\x18\x02 \x01(\r\x12\x16\n\x0ein_logon_surge\x18\x03 \x01(\x08\"\x1e\n\x1c\x43MsgGCToClientRequestDropped\"\xf7\x02\n*CWorkshop_PopulateItemDescriptions_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x61\n\tlanguages\x18\x02 \x03(\x0b\x32N.dota.CWorkshop_PopulateItemDescriptions_Request.ItemDescriptionsLanguageBlock\x1a\x45\n\x15SingleItemDescription\x12\x12\n\ngameitemid\x18\x01 \x01(\r\x12\x18\n\x10item_description\x18\x02 \x01(\t\x1a\x8f\x01\n\x1dItemDescriptionsLanguageBlock\x12\x10\n\x08language\x18\x01 \x01(\t\x12\\\n\x0c\x64\x65scriptions\x18\x02 \x03(\x0b\x32\x46.dota.CWorkshop_PopulateItemDescriptions_Request.SingleItemDescription\"F\n!CWorkshop_GetContributors_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\ngameitemid\x18\x02 \x01(\r\":\n\"CWorkshop_GetContributors_Response\x12\x14\n\x0c\x63ontributors\x18\x01 \x03(\x06\"\xb3\x04\n%CWorkshop_SetItemPaymentRules_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\ngameitemid\x18\x02 \x01(\r\x12\x66\n\x19\x61ssociated_workshop_files\x18\x03 \x03(\x0b\x32\x43.dota.CWorkshop_SetItemPaymentRules_Request.WorkshopItemPaymentRule\x12\\\n\x10partner_accounts\x18\x04 \x03(\x0b\x32\x42.dota.CWorkshop_SetItemPaymentRules_Request.PartnerItemPaymentRule\x12\x15\n\rvalidate_only\x18\x05 \x01(\x08\x12(\n make_workshop_files_subscribable\x18\x06 \x01(\x08\x1a|\n\x17WorkshopItemPaymentRule\x12\x18\n\x10workshop_file_id\x18\x01 \x01(\x04\x12\x1a\n\x12revenue_percentage\x18\x02 \x01(\x02\x12\x18\n\x10rule_description\x18\x03 \x01(\t\x12\x11\n\trule_type\x18\x04 \x01(\r\x1a\x62\n\x16PartnerItemPaymentRule\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x1a\n\x12revenue_percentage\x18\x02 \x01(\x02\x12\x18\n\x10rule_description\x18\x03 \x01(\t\"C\n&CWorkshop_SetItemPaymentRules_Response\x12\x19\n\x11validation_errors\x18\x01 \x03(\t\"\xf4\x01\n\x1f\x43\x43ommunity_ClanAnnouncementInfo\x12\x0b\n\x03gid\x18\x01 \x01(\x04\x12\x0e\n\x06\x63lanid\x18\x02 \x01(\x04\x12\x10\n\x08posterid\x18\x03 \x01(\x04\x12\x10\n\x08headline\x18\x04 \x01(\t\x12\x10\n\x08posttime\x18\x05 \x01(\r\x12\x12\n\nupdatetime\x18\x06 \x01(\r\x12\x0c\n\x04\x62ody\x18\x07 \x01(\t\x12\x14\n\x0c\x63ommentcount\x18\x08 \x01(\x05\x12\x0c\n\x04tags\x18\t \x03(\t\x12\x10\n\x08language\x18\n \x01(\x05\x12\x0e\n\x06hidden\x18\x0b \x01(\x08\x12\x16\n\x0e\x66orum_topic_id\x18\x0c \x01(\x06\"\xc6\x02\n\'CCommunity_GetClanAnnouncements_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x04\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12\x10\n\x08maxchars\x18\x04 \x01(\r\x12\x12\n\nstrip_html\x18\x05 \x01(\x08\x12\x15\n\rrequired_tags\x18\x06 \x03(\t\x12\x17\n\x0frequire_no_tags\x18\x07 \x01(\x08\x12\x1b\n\x13language_preference\x18\x08 \x03(\r\x12\x13\n\x0bhidden_only\x18\t \x01(\x08\x12\x10\n\x08only_gid\x18\n \x01(\x08\x12\x19\n\x11rtime_oldest_date\x18\x0b \x01(\r\x12\x16\n\x0einclude_hidden\x18\x0c \x01(\x08\x12\x1e\n\x16include_partner_events\x18\r \x01(\x08\"\x8e\x01\n(CCommunity_GetClanAnnouncements_Response\x12\x10\n\x08maxchars\x18\x01 \x01(\r\x12\x12\n\nstrip_html\x18\x02 \x01(\x08\x12<\n\rannouncements\x18\x03 \x03(\x0b\x32%.dota.CCommunity_ClanAnnouncementInfo\"p\n$CBroadcast_PostGameDataFrame_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07steamid\x18\x02 \x01(\x06\x12\x14\n\x0c\x62roadcast_id\x18\x03 \x01(\x06\x12\x12\n\nframe_data\x18\x04 \x01(\x0c\"\x8b\x03\n\x15\x43MsgSerializedSOCache\x12\x14\n\x0c\x66ile_version\x18\x01 \x01(\r\x12\x31\n\x06\x63\x61\x63hes\x18\x02 \x03(\x0b\x32!.dota.CMsgSerializedSOCache.Cache\x12\x1f\n\x17gc_socache_file_version\x18\x03 \x01(\r\x1a>\n\tTypeCache\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0f\n\x07objects\x18\x02 \x03(\x0c\x12\x12\n\nservice_id\x18\x03 \x01(\r\x1a\xc7\x01\n\x05\x43\x61\x63he\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\n\n\x02id\x18\x02 \x01(\x04\x12;\n\x08versions\x18\x03 \x03(\x0b\x32).dota.CMsgSerializedSOCache.Cache.Version\x12:\n\x0btype_caches\x18\x04 \x03(\x0b\x32%.dota.CMsgSerializedSOCache.TypeCache\x1a+\n\x07Version\x12\x0f\n\x07service\x18\x01 \x01(\r\x12\x0f\n\x07version\x18\x02 \x01(\x04\"G\n\x1f\x43MsgGCToClientPollConvarRequest\x12\x13\n\x0b\x63onvar_name\x18\x01 \x01(\t\x12\x0f\n\x07poll_id\x18\x02 \x01(\r\"I\n CMsgGCToClientPollConvarResponse\x12\x0f\n\x07poll_id\x18\x01 \x01(\r\x12\x14\n\x0c\x63onvar_value\x18\x02 \x01(\t\"E\n\x1b\x43GCMsgCompressedMsgToClient\x12\x0e\n\x06msg_id\x18\x01 \x01(\r\x12\x16\n\x0e\x63ompressed_msg\x18\x02 \x01(\x0c\"\x8e\x01\n CMsgGCToGCMasterBroadcastMessage\x12\x18\n\x10users_per_second\x18\x01 \x01(\r\x12\x15\n\rsend_to_users\x18\x02 \x01(\x08\x12\x17\n\x0fsend_to_servers\x18\x03 \x01(\x08\x12\x0e\n\x06msg_id\x18\x04 \x01(\r\x12\x10\n\x08msg_data\x18\x05 \x01(\x0c\"n\n CMsgGCToGCMasterSubscribeToCache\x12\x11\n\tsoid_type\x18\x01 \x01(\r\x12\x0f\n\x07soid_id\x18\x02 \x01(\x06\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x03 \x03(\r\x12\x11\n\tsteam_ids\x18\x04 \x03(\x06\"*\n(CMsgGCToGCMasterSubscribeToCacheResponse\"f\n%CMsgGCToGCMasterSubscribeToCacheAsync\x12=\n\rsubscribe_msg\x18\x01 \x01(\x0b\x32&.dota.CMsgGCToGCMasterSubscribeToCache\"r\n$CMsgGCToGCMasterUnsubscribeFromCache\x12\x11\n\tsoid_type\x18\x01 \x01(\r\x12\x0f\n\x07soid_id\x18\x02 \x01(\x06\x12\x13\n\x0b\x61\x63\x63ount_ids\x18\x03 \x03(\r\x12\x11\n\tsteam_ids\x18\x04 \x03(\x06\"B\n\x1c\x43MsgGCToGCMasterDestroyCache\x12\x11\n\tsoid_type\x18\x01 \x01(\r\x12\x0f\n\x07soid_id\x18\x02 \x01(\x06*5\n\rESourceEngine\x12\x11\n\rk_ESE_Source1\x10\x00\x12\x11\n\rk_ESE_Source2\x10\x01*V\n\x12PartnerAccountType\x12\x10\n\x0cPARTNER_NONE\x10\x00\x12\x19\n\x15PARTNER_PERFECT_WORLD\x10\x01\x12\x13\n\x0fPARTNER_INVALID\x10\x03*\xa0\x02\n\x12GCConnectionStatus\x12#\n\x1fGCConnectionStatus_HAVE_SESSION\x10\x00\x12$\n GCConnectionStatus_GC_GOING_DOWN\x10\x01\x12!\n\x1dGCConnectionStatus_NO_SESSION\x10\x02\x12\x30\n,GCConnectionStatus_NO_SESSION_IN_LOGON_QUEUE\x10\x03\x12\x1f\n\x1bGCConnectionStatus_NO_STEAM\x10\x04\x12 \n\x1cGCConnectionStatus_SUSPENDED\x10\x05\x12\'\n#GCConnectionStatus_STEAM_GOING_DOWN\x10\x06\x42\x05H\x01\x90\x01\x00')
  ,
  dependencies=[steammessages__pb2.DESCRIPTOR,])

_ESOURCEENGINE = _descriptor.EnumDescriptor(
  name='ESourceEngine',
  full_name='dota.ESourceEngine',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ESE_Source1', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_ESE_Source2', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7697,
  serialized_end=7750,
)
_sym_db.RegisterEnumDescriptor(_ESOURCEENGINE)

ESourceEngine = enum_type_wrapper.EnumTypeWrapper(_ESOURCEENGINE)
_PARTNERACCOUNTTYPE = _descriptor.EnumDescriptor(
  name='PartnerAccountType',
  full_name='dota.PartnerAccountType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARTNER_NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARTNER_PERFECT_WORLD', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARTNER_INVALID', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7752,
  serialized_end=7838,
)
_sym_db.RegisterEnumDescriptor(_PARTNERACCOUNTTYPE)

PartnerAccountType = enum_type_wrapper.EnumTypeWrapper(_PARTNERACCOUNTTYPE)
_GCCONNECTIONSTATUS = _descriptor.EnumDescriptor(
  name='GCConnectionStatus',
  full_name='dota.GCConnectionStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GCConnectionStatus_HAVE_SESSION', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GCConnectionStatus_GC_GOING_DOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GCConnectionStatus_NO_SESSION', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GCConnectionStatus_NO_SESSION_IN_LOGON_QUEUE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GCConnectionStatus_NO_STEAM', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GCConnectionStatus_SUSPENDED', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GCConnectionStatus_STEAM_GOING_DOWN', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7841,
  serialized_end=8129,
)
_sym_db.RegisterEnumDescriptor(_GCCONNECTIONSTATUS)

GCConnectionStatus = enum_type_wrapper.EnumTypeWrapper(_GCCONNECTIONSTATUS)
k_ESE_Source1 = 0
k_ESE_Source2 = 1
PARTNER_NONE = 0
PARTNER_PERFECT_WORLD = 1
PARTNER_INVALID = 3
GCConnectionStatus_HAVE_SESSION = 0
GCConnectionStatus_GC_GOING_DOWN = 1
GCConnectionStatus_NO_SESSION = 2
GCConnectionStatus_NO_SESSION_IN_LOGON_QUEUE = 3
GCConnectionStatus_NO_STEAM = 4
GCConnectionStatus_SUSPENDED = 5
GCConnectionStatus_STEAM_GOING_DOWN = 6



_CMSGSHA1DIGEST = _descriptor.Descriptor(
  name='CMsgSHA1Digest',
  full_name='dota.CMsgSHA1Digest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block1', full_name='dota.CMsgSHA1Digest.block1', index=0,
      number=1, type=6, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block2', full_name='dota.CMsgSHA1Digest.block2', index=1,
      number=2, type=6, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block3', full_name='dota.CMsgSHA1Digest.block3', index=2,
      number=3, type=7, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=117,
)


_CMSGSOIDOWNER = _descriptor.Descriptor(
  name='CMsgSOIDOwner',
  full_name='dota.CMsgSOIDOwner',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='dota.CMsgSOIDOwner.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='dota.CMsgSOIDOwner.id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=160,
)


_CMSGSOSINGLEOBJECT = _descriptor.Descriptor(
  name='CMsgSOSingleObject',
  full_name='dota.CMsgSOSingleObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type_id', full_name='dota.CMsgSOSingleObject.type_id', index=0,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_data', full_name='dota.CMsgSOSingleObject.object_data', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='dota.CMsgSOSingleObject.version', index=2,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_soid', full_name='dota.CMsgSOSingleObject.owner_soid', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_id', full_name='dota.CMsgSOSingleObject.service_id', index=4,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=299,
)


_CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT = _descriptor.Descriptor(
  name='SingleObject',
  full_name='dota.CMsgSOMultipleObjects.SingleObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type_id', full_name='dota.CMsgSOMultipleObjects.SingleObject.type_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_data', full_name='dota.CMsgSOMultipleObjects.SingleObject.object_data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('\200\227\"\200\002\210\227\"\200\010'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=605,
  serialized_end=669,
)

_CMSGSOMULTIPLEOBJECTS = _descriptor.Descriptor(
  name='CMsgSOMultipleObjects',
  full_name='dota.CMsgSOMultipleObjects',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects_modified', full_name='dota.CMsgSOMultipleObjects.objects_modified', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='dota.CMsgSOMultipleObjects.version', index=1,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objects_added', full_name='dota.CMsgSOMultipleObjects.objects_added', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objects_removed', full_name='dota.CMsgSOMultipleObjects.objects_removed', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_soid', full_name='dota.CMsgSOMultipleObjects.owner_soid', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_id', full_name='dota.CMsgSOMultipleObjects.service_id', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=669,
)


_CMSGSOCACHESUBSCRIBED_SUBSCRIBEDTYPE = _descriptor.Descriptor(
  name='SubscribedType',
  full_name='dota.CMsgSOCacheSubscribed.SubscribedType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type_id', full_name='dota.CMsgSOCacheSubscribed.SubscribedType.type_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_data', full_name='dota.CMsgSOCacheSubscribed.SubscribedType.object_data', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=880,
  serialized_end=934,
)

_CMSGSOCACHESUBSCRIBED = _descriptor.Descriptor(
  name='CMsgSOCacheSubscribed',
  full_name='dota.CMsgSOCacheSubscribed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects', full_name='dota.CMsgSOCacheSubscribed.objects', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='dota.CMsgSOCacheSubscribed.version', index=1,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_soid', full_name='dota.CMsgSOCacheSubscribed.owner_soid', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_id', full_name='dota.CMsgSOCacheSubscribed.service_id', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_list', full_name='dota.CMsgSOCacheSubscribed.service_list', index=4,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sync_version', full_name='dota.CMsgSOCacheSubscribed.sync_version', index=5,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSOCACHESUBSCRIBED_SUBSCRIBEDTYPE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=934,
)


_CMSGSOCACHESUBSCRIBEDUPTODATE = _descriptor.Descriptor(
  name='CMsgSOCacheSubscribedUpToDate',
  full_name='dota.CMsgSOCacheSubscribedUpToDate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='dota.CMsgSOCacheSubscribedUpToDate.version', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_soid', full_name='dota.CMsgSOCacheSubscribedUpToDate.owner_soid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_id', full_name='dota.CMsgSOCacheSubscribedUpToDate.service_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_list', full_name='dota.CMsgSOCacheSubscribedUpToDate.service_list', index=3,
      number=4, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sync_version', full_name='dota.CMsgSOCacheSubscribedUpToDate.sync_version', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=937,
  serialized_end=1090,
)


_CMSGSOCACHEUNSUBSCRIBED = _descriptor.Descriptor(
  name='CMsgSOCacheUnsubscribed',
  full_name='dota.CMsgSOCacheUnsubscribed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_soid', full_name='dota.CMsgSOCacheUnsubscribed.owner_soid', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1092,
  serialized_end=1158,
)


_CMSGSOCACHESUBSCRIPTIONCHECK = _descriptor.Descriptor(
  name='CMsgSOCacheSubscriptionCheck',
  full_name='dota.CMsgSOCacheSubscriptionCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='dota.CMsgSOCacheSubscriptionCheck.version', index=0,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_soid', full_name='dota.CMsgSOCacheSubscriptionCheck.owner_soid', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_id', full_name='dota.CMsgSOCacheSubscriptionCheck.service_id', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_list', full_name='dota.CMsgSOCacheSubscriptionCheck.service_list', index=3,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sync_version', full_name='dota.CMsgSOCacheSubscriptionCheck.sync_version', index=4,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1161,
  serialized_end=1313,
)


_CMSGSOCACHESUBSCRIPTIONREFRESH = _descriptor.Descriptor(
  name='CMsgSOCacheSubscriptionRefresh',
  full_name='dota.CMsgSOCacheSubscriptionRefresh',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='owner_soid', full_name='dota.CMsgSOCacheSubscriptionRefresh.owner_soid', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1315,
  serialized_end=1388,
)


_CMSGSOCACHEVERSION = _descriptor.Descriptor(
  name='CMsgSOCacheVersion',
  full_name='dota.CMsgSOCacheVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='dota.CMsgSOCacheVersion.version', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1390,
  serialized_end=1427,
)


_CMSGGCMULTIPLEXMESSAGE = _descriptor.Descriptor(
  name='CMsgGCMultiplexMessage',
  full_name='dota.CMsgGCMultiplexMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msgtype', full_name='dota.CMsgGCMultiplexMessage.msgtype', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='dota.CMsgGCMultiplexMessage.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steamids', full_name='dota.CMsgGCMultiplexMessage.steamids', index=2,
      number=3, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1429,
  serialized_end=1505,
)


_CMSGGCTOGCSUBGCSTARTING = _descriptor.Descriptor(
  name='CMsgGCToGCSubGCStarting',
  full_name='dota.CMsgGCToGCSubGCStarting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dir_index', full_name='dota.CMsgGCToGCSubGCStarting.dir_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1507,
  serialized_end=1551,
)


_CGCTOGCMSGMASTERACK_PROCESS = _descriptor.Descriptor(
  name='Process',
  full_name='dota.CGCToGCMsgMasterAck.Process',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dir_index', full_name='dota.CGCToGCMsgMasterAck.Process.dir_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_instances', full_name='dota.CGCToGCMsgMasterAck.Process.type_instances', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1694,
  serialized_end=1746,
)

_CGCTOGCMSGMASTERACK = _descriptor.Descriptor(
  name='CGCToGCMsgMasterAck',
  full_name='dota.CGCToGCMsgMasterAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dir_index', full_name='dota.CGCToGCMsgMasterAck.dir_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='machine_name', full_name='dota.CGCToGCMsgMasterAck.machine_name', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_name', full_name='dota.CGCToGCMsgMasterAck.process_name', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='directory', full_name='dota.CGCToGCMsgMasterAck.directory', index=3,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CGCTOGCMSGMASTERACK_PROCESS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1554,
  serialized_end=1746,
)


_CGCTOGCMSGMASTERACK_RESPONSE = _descriptor.Descriptor(
  name='CGCToGCMsgMasterAck_Response',
  full_name='dota.CGCToGCMsgMasterAck_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='dota.CGCToGCMsgMasterAck_Response.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1748,
  serialized_end=1798,
)


_CMSGGCTOGCUNIVERSESTARTUP = _descriptor.Descriptor(
  name='CMsgGCToGCUniverseStartup',
  full_name='dota.CMsgGCToGCUniverseStartup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_initial_startup', full_name='dota.CMsgGCToGCUniverseStartup.is_initial_startup', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1800,
  serialized_end=1855,
)


_CMSGGCTOGCUNIVERSESTARTUPRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToGCUniverseStartupResponse',
  full_name='dota.CMsgGCToGCUniverseStartupResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='dota.CMsgGCToGCUniverseStartupResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1857,
  serialized_end=1909,
)


_CGCTOGCMSGMASTERSTARTUPCOMPLETE_GCINFO = _descriptor.Descriptor(
  name='GCInfo',
  full_name='dota.CGCToGCMsgMasterStartupComplete.GCInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dir_index', full_name='dota.CGCToGCMsgMasterStartupComplete.GCInfo.dir_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='machine_name', full_name='dota.CGCToGCMsgMasterStartupComplete.GCInfo.machine_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2010,
  serialized_end=2059,
)

_CGCTOGCMSGMASTERSTARTUPCOMPLETE = _descriptor.Descriptor(
  name='CGCToGCMsgMasterStartupComplete',
  full_name='dota.CGCToGCMsgMasterStartupComplete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gc_info', full_name='dota.CGCToGCMsgMasterStartupComplete.gc_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CGCTOGCMSGMASTERSTARTUPCOMPLETE_GCINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1912,
  serialized_end=2059,
)


_CGCTOGCMSGROUTED = _descriptor.Descriptor(
  name='CGCToGCMsgRouted',
  full_name='dota.CGCToGCMsgRouted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg_type', full_name='dota.CGCToGCMsgRouted.msg_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='dota.CGCToGCMsgRouted.sender_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='net_message', full_name='dota.CGCToGCMsgRouted.net_message', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2061,
  serialized_end=2137,
)


_CGCTOGCMSGROUTEDREPLY = _descriptor.Descriptor(
  name='CGCToGCMsgRoutedReply',
  full_name='dota.CGCToGCMsgRoutedReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg_type', full_name='dota.CGCToGCMsgRoutedReply.msg_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='net_message', full_name='dota.CGCToGCMsgRoutedReply.net_message', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2139,
  serialized_end=2201,
)


_CMSGGCUPDATESUBGCSESSIONINFO_CMSGUPDATE = _descriptor.Descriptor(
  name='CMsgUpdate',
  full_name='dota.CMsgGCUpdateSubGCSessionInfo.CMsgUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='dota.CMsgGCUpdateSubGCSessionInfo.CMsgUpdate.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip', full_name='dota.CMsgGCUpdateSubGCSessionInfo.CMsgUpdate.ip', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trusted', full_name='dota.CMsgGCUpdateSubGCSessionInfo.CMsgUpdate.trusted', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2300,
  serialized_end=2358,
)

_CMSGGCUPDATESUBGCSESSIONINFO = _descriptor.Descriptor(
  name='CMsgGCUpdateSubGCSessionInfo',
  full_name='dota.CMsgGCUpdateSubGCSessionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='updates', full_name='dota.CMsgGCUpdateSubGCSessionInfo.updates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCUPDATESUBGCSESSIONINFO_CMSGUPDATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2204,
  serialized_end=2358,
)


_CMSGGCREQUESTSUBGCSESSIONINFO = _descriptor.Descriptor(
  name='CMsgGCRequestSubGCSessionInfo',
  full_name='dota.CMsgGCRequestSubGCSessionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='dota.CMsgGCRequestSubGCSessionInfo.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2360,
  serialized_end=2408,
)


_CMSGGCREQUESTSUBGCSESSIONINFORESPONSE = _descriptor.Descriptor(
  name='CMsgGCRequestSubGCSessionInfoResponse',
  full_name='dota.CMsgGCRequestSubGCSessionInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='dota.CMsgGCRequestSubGCSessionInfoResponse.ip', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trusted', full_name='dota.CMsgGCRequestSubGCSessionInfoResponse.trusted', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='dota.CMsgGCRequestSubGCSessionInfoResponse.port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='success', full_name='dota.CMsgGCRequestSubGCSessionInfoResponse.success', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2410,
  serialized_end=2509,
)


_CMSGSOCACHEHAVEVERSION = _descriptor.Descriptor(
  name='CMsgSOCacheHaveVersion',
  full_name='dota.CMsgSOCacheHaveVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='soid', full_name='dota.CMsgSOCacheHaveVersion.soid', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='dota.CMsgSOCacheHaveVersion.version', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_id', full_name='dota.CMsgSOCacheHaveVersion.service_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cached_file_version', full_name='dota.CMsgSOCacheHaveVersion.cached_file_version', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2511,
  serialized_end=2636,
)


_CMSGCLIENTHELLO = _descriptor.Descriptor(
  name='CMsgClientHello',
  full_name='dota.CMsgClientHello',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='dota.CMsgClientHello.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='socache_have_versions', full_name='dota.CMsgClientHello.socache_have_versions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_session_need', full_name='dota.CMsgClientHello.client_session_need', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_launcher', full_name='dota.CMsgClientHello.client_launcher', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secret_key', full_name='dota.CMsgClientHello.secret_key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_language', full_name='dota.CMsgClientHello.client_language', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='engine', full_name='dota.CMsgClientHello.engine', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steamdatagram_login', full_name='dota.CMsgClientHello.steamdatagram_login', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='platform_id', full_name='dota.CMsgClientHello.platform_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_msg', full_name='dota.CMsgClientHello.game_msg', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2639,
  serialized_end=2993,
)


_CMSGCLIENTWELCOME_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='dota.CMsgClientWelcome.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude', full_name='dota.CMsgClientWelcome.Location.latitude', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='dota.CMsgClientWelcome.Location.longitude', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country', full_name='dota.CMsgClientWelcome.Location.country', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3374,
  serialized_end=3438,
)

_CMSGCLIENTWELCOME = _descriptor.Descriptor(
  name='CMsgClientWelcome',
  full_name='dota.CMsgClientWelcome',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='dota.CMsgClientWelcome.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='game_data', full_name='dota.CMsgClientWelcome.game_data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outofdate_subscribed_caches', full_name='dota.CMsgClientWelcome.outofdate_subscribed_caches', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uptodate_subscribed_caches', full_name='dota.CMsgClientWelcome.uptodate_subscribed_caches', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='dota.CMsgClientWelcome.location', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='save_game_key', full_name='dota.CMsgClientWelcome.save_game_key', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_schema_crc', full_name='dota.CMsgClientWelcome.item_schema_crc', index=6,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='items_game_url', full_name='dota.CMsgClientWelcome.items_game_url', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gc_socache_file_version', full_name='dota.CMsgClientWelcome.gc_socache_file_version', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txn_country_code', full_name='dota.CMsgClientWelcome.txn_country_code', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTWELCOME_LOCATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2996,
  serialized_end=3438,
)


_CMSGCONNECTIONSTATUS = _descriptor.Descriptor(
  name='CMsgConnectionStatus',
  full_name='dota.CMsgConnectionStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='dota.CMsgConnectionStatus.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_session_need', full_name='dota.CMsgConnectionStatus.client_session_need', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue_position', full_name='dota.CMsgConnectionStatus.queue_position', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue_size', full_name='dota.CMsgConnectionStatus.queue_size', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wait_seconds', full_name='dota.CMsgConnectionStatus.wait_seconds', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='estimated_wait_seconds_remaining', full_name='dota.CMsgConnectionStatus.estimated_wait_seconds_remaining', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3441,
  serialized_end=3675,
)


_CMSGGCTOGCSOCACHESUBSCRIBE_CMSGHAVEVERSIONS = _descriptor.Descriptor(
  name='CMsgHaveVersions',
  full_name='dota.CMsgGCToGCSOCacheSubscribe.CMsgHaveVersions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_id', full_name='dota.CMsgGCToGCSOCacheSubscribe.CMsgHaveVersions.service_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='dota.CMsgGCToGCSOCacheSubscribe.CMsgHaveVersions.version', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3876,
  serialized_end=3931,
)

_CMSGGCTOGCSOCACHESUBSCRIBE = _descriptor.Descriptor(
  name='CMsgGCToGCSOCacheSubscribe',
  full_name='dota.CMsgGCToGCSOCacheSubscribe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subscriber', full_name='dota.CMsgGCToGCSOCacheSubscribe.subscriber', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subscribe_to_id', full_name='dota.CMsgGCToGCSOCacheSubscribe.subscribe_to_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sync_version', full_name='dota.CMsgGCToGCSOCacheSubscribe.sync_version', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='have_versions', full_name='dota.CMsgGCToGCSOCacheSubscribe.have_versions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subscribe_to_type', full_name='dota.CMsgGCToGCSOCacheSubscribe.subscribe_to_type', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGGCTOGCSOCACHESUBSCRIBE_CMSGHAVEVERSIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3678,
  serialized_end=3931,
)


_CMSGGCTOGCSOCACHEUNSUBSCRIBE = _descriptor.Descriptor(
  name='CMsgGCToGCSOCacheUnsubscribe',
  full_name='dota.CMsgGCToGCSOCacheUnsubscribe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subscriber', full_name='dota.CMsgGCToGCSOCacheUnsubscribe.subscriber', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unsubscribe_from_id', full_name='dota.CMsgGCToGCSOCacheUnsubscribe.unsubscribe_from_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unsubscribe_from_type', full_name='dota.CMsgGCToGCSOCacheUnsubscribe.unsubscribe_from_type', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3933,
  serialized_end=4043,
)


_CMSGGCCLIENTPING = _descriptor.Descriptor(
  name='CMsgGCClientPing',
  full_name='dota.CMsgGCClientPing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4045,
  serialized_end=4063,
)


_CMSGGCTOGCFORWARDACCOUNTDETAILS = _descriptor.Descriptor(
  name='CMsgGCToGCForwardAccountDetails',
  full_name='dota.CMsgGCToGCForwardAccountDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='dota.CMsgGCToGCForwardAccountDetails.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_details', full_name='dota.CMsgGCToGCForwardAccountDetails.account_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='age_seconds', full_name='dota.CMsgGCToGCForwardAccountDetails.age_seconds', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4066,
  serialized_end=4209,
)


_CMSGGCTOGCLOADSESSIONSOCACHE = _descriptor.Descriptor(
  name='CMsgGCToGCLoadSessionSOCache',
  full_name='dota.CMsgGCToGCLoadSessionSOCache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CMsgGCToGCLoadSessionSOCache.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward_account_details', full_name='dota.CMsgGCToGCLoadSessionSOCache.forward_account_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4211,
  serialized_end=4333,
)


_CMSGGCTOGCLOADSESSIONSOCACHERESPONSE = _descriptor.Descriptor(
  name='CMsgGCToGCLoadSessionSOCacheResponse',
  full_name='dota.CMsgGCToGCLoadSessionSOCacheResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4335,
  serialized_end=4373,
)


_CMSGGCTOGCUPDATESESSIONSTATS = _descriptor.Descriptor(
  name='CMsgGCToGCUpdateSessionStats',
  full_name='dota.CMsgGCToGCUpdateSessionStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_sessions', full_name='dota.CMsgGCToGCUpdateSessionStats.user_sessions', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_sessions', full_name='dota.CMsgGCToGCUpdateSessionStats.server_sessions', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_logon_surge', full_name='dota.CMsgGCToGCUpdateSessionStats.in_logon_surge', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4375,
  serialized_end=4477,
)


_CMSGGCTOCLIENTREQUESTDROPPED = _descriptor.Descriptor(
  name='CMsgGCToClientRequestDropped',
  full_name='dota.CMsgGCToClientRequestDropped',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4479,
  serialized_end=4509,
)


_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_SINGLEITEMDESCRIPTION = _descriptor.Descriptor(
  name='SingleItemDescription',
  full_name='dota.CWorkshop_PopulateItemDescriptions_Request.SingleItemDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gameitemid', full_name='dota.CWorkshop_PopulateItemDescriptions_Request.SingleItemDescription.gameitemid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_description', full_name='dota.CWorkshop_PopulateItemDescriptions_Request.SingleItemDescription.item_description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4672,
  serialized_end=4741,
)

_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_ITEMDESCRIPTIONSLANGUAGEBLOCK = _descriptor.Descriptor(
  name='ItemDescriptionsLanguageBlock',
  full_name='dota.CWorkshop_PopulateItemDescriptions_Request.ItemDescriptionsLanguageBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='dota.CWorkshop_PopulateItemDescriptions_Request.ItemDescriptionsLanguageBlock.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='descriptions', full_name='dota.CWorkshop_PopulateItemDescriptions_Request.ItemDescriptionsLanguageBlock.descriptions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4744,
  serialized_end=4887,
)

_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST = _descriptor.Descriptor(
  name='CWorkshop_PopulateItemDescriptions_Request',
  full_name='dota.CWorkshop_PopulateItemDescriptions_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='dota.CWorkshop_PopulateItemDescriptions_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='languages', full_name='dota.CWorkshop_PopulateItemDescriptions_Request.languages', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_SINGLEITEMDESCRIPTION, _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_ITEMDESCRIPTIONSLANGUAGEBLOCK, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4512,
  serialized_end=4887,
)


_CWORKSHOP_GETCONTRIBUTORS_REQUEST = _descriptor.Descriptor(
  name='CWorkshop_GetContributors_Request',
  full_name='dota.CWorkshop_GetContributors_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='dota.CWorkshop_GetContributors_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gameitemid', full_name='dota.CWorkshop_GetContributors_Request.gameitemid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4889,
  serialized_end=4959,
)


_CWORKSHOP_GETCONTRIBUTORS_RESPONSE = _descriptor.Descriptor(
  name='CWorkshop_GetContributors_Response',
  full_name='dota.CWorkshop_GetContributors_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='contributors', full_name='dota.CWorkshop_GetContributors_Response.contributors', index=0,
      number=1, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4961,
  serialized_end=5019,
)


_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_WORKSHOPITEMPAYMENTRULE = _descriptor.Descriptor(
  name='WorkshopItemPaymentRule',
  full_name='dota.CWorkshop_SetItemPaymentRules_Request.WorkshopItemPaymentRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='workshop_file_id', full_name='dota.CWorkshop_SetItemPaymentRules_Request.WorkshopItemPaymentRule.workshop_file_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revenue_percentage', full_name='dota.CWorkshop_SetItemPaymentRules_Request.WorkshopItemPaymentRule.revenue_percentage', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_description', full_name='dota.CWorkshop_SetItemPaymentRules_Request.WorkshopItemPaymentRule.rule_description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_type', full_name='dota.CWorkshop_SetItemPaymentRules_Request.WorkshopItemPaymentRule.rule_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5361,
  serialized_end=5485,
)

_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_PARTNERITEMPAYMENTRULE = _descriptor.Descriptor(
  name='PartnerItemPaymentRule',
  full_name='dota.CWorkshop_SetItemPaymentRules_Request.PartnerItemPaymentRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='dota.CWorkshop_SetItemPaymentRules_Request.PartnerItemPaymentRule.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revenue_percentage', full_name='dota.CWorkshop_SetItemPaymentRules_Request.PartnerItemPaymentRule.revenue_percentage', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_description', full_name='dota.CWorkshop_SetItemPaymentRules_Request.PartnerItemPaymentRule.rule_description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5487,
  serialized_end=5585,
)

_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST = _descriptor.Descriptor(
  name='CWorkshop_SetItemPaymentRules_Request',
  full_name='dota.CWorkshop_SetItemPaymentRules_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='dota.CWorkshop_SetItemPaymentRules_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gameitemid', full_name='dota.CWorkshop_SetItemPaymentRules_Request.gameitemid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='associated_workshop_files', full_name='dota.CWorkshop_SetItemPaymentRules_Request.associated_workshop_files', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partner_accounts', full_name='dota.CWorkshop_SetItemPaymentRules_Request.partner_accounts', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='dota.CWorkshop_SetItemPaymentRules_Request.validate_only', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='make_workshop_files_subscribable', full_name='dota.CWorkshop_SetItemPaymentRules_Request.make_workshop_files_subscribable', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_WORKSHOPITEMPAYMENTRULE, _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_PARTNERITEMPAYMENTRULE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5022,
  serialized_end=5585,
)


_CWORKSHOP_SETITEMPAYMENTRULES_RESPONSE = _descriptor.Descriptor(
  name='CWorkshop_SetItemPaymentRules_Response',
  full_name='dota.CWorkshop_SetItemPaymentRules_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='validation_errors', full_name='dota.CWorkshop_SetItemPaymentRules_Response.validation_errors', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5587,
  serialized_end=5654,
)


_CCOMMUNITY_CLANANNOUNCEMENTINFO = _descriptor.Descriptor(
  name='CCommunity_ClanAnnouncementInfo',
  full_name='dota.CCommunity_ClanAnnouncementInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gid', full_name='dota.CCommunity_ClanAnnouncementInfo.gid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clanid', full_name='dota.CCommunity_ClanAnnouncementInfo.clanid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posterid', full_name='dota.CCommunity_ClanAnnouncementInfo.posterid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headline', full_name='dota.CCommunity_ClanAnnouncementInfo.headline', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posttime', full_name='dota.CCommunity_ClanAnnouncementInfo.posttime', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updatetime', full_name='dota.CCommunity_ClanAnnouncementInfo.updatetime', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='dota.CCommunity_ClanAnnouncementInfo.body', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commentcount', full_name='dota.CCommunity_ClanAnnouncementInfo.commentcount', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='dota.CCommunity_ClanAnnouncementInfo.tags', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='dota.CCommunity_ClanAnnouncementInfo.language', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='dota.CCommunity_ClanAnnouncementInfo.hidden', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forum_topic_id', full_name='dota.CCommunity_ClanAnnouncementInfo.forum_topic_id', index=11,
      number=12, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5657,
  serialized_end=5901,
)


_CCOMMUNITY_GETCLANANNOUNCEMENTS_REQUEST = _descriptor.Descriptor(
  name='CCommunity_GetClanAnnouncements_Request',
  full_name='dota.CCommunity_GetClanAnnouncements_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='dota.CCommunity_GetClanAnnouncements_Request.steamid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='dota.CCommunity_GetClanAnnouncements_Request.offset', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='dota.CCommunity_GetClanAnnouncements_Request.count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxchars', full_name='dota.CCommunity_GetClanAnnouncements_Request.maxchars', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strip_html', full_name='dota.CCommunity_GetClanAnnouncements_Request.strip_html', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='required_tags', full_name='dota.CCommunity_GetClanAnnouncements_Request.required_tags', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='require_no_tags', full_name='dota.CCommunity_GetClanAnnouncements_Request.require_no_tags', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language_preference', full_name='dota.CCommunity_GetClanAnnouncements_Request.language_preference', index=7,
      number=8, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden_only', full_name='dota.CCommunity_GetClanAnnouncements_Request.hidden_only', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='only_gid', full_name='dota.CCommunity_GetClanAnnouncements_Request.only_gid', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rtime_oldest_date', full_name='dota.CCommunity_GetClanAnnouncements_Request.rtime_oldest_date', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='include_hidden', full_name='dota.CCommunity_GetClanAnnouncements_Request.include_hidden', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='include_partner_events', full_name='dota.CCommunity_GetClanAnnouncements_Request.include_partner_events', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5904,
  serialized_end=6230,
)


_CCOMMUNITY_GETCLANANNOUNCEMENTS_RESPONSE = _descriptor.Descriptor(
  name='CCommunity_GetClanAnnouncements_Response',
  full_name='dota.CCommunity_GetClanAnnouncements_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='maxchars', full_name='dota.CCommunity_GetClanAnnouncements_Response.maxchars', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strip_html', full_name='dota.CCommunity_GetClanAnnouncements_Response.strip_html', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='announcements', full_name='dota.CCommunity_GetClanAnnouncements_Response.announcements', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6233,
  serialized_end=6375,
)


_CBROADCAST_POSTGAMEDATAFRAME_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_PostGameDataFrame_Request',
  full_name='dota.CBroadcast_PostGameDataFrame_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='dota.CBroadcast_PostGameDataFrame_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steamid', full_name='dota.CBroadcast_PostGameDataFrame_Request.steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='dota.CBroadcast_PostGameDataFrame_Request.broadcast_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_data', full_name='dota.CBroadcast_PostGameDataFrame_Request.frame_data', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6377,
  serialized_end=6489,
)


_CMSGSERIALIZEDSOCACHE_TYPECACHE = _descriptor.Descriptor(
  name='TypeCache',
  full_name='dota.CMsgSerializedSOCache.TypeCache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='dota.CMsgSerializedSOCache.TypeCache.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objects', full_name='dota.CMsgSerializedSOCache.TypeCache.objects', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_id', full_name='dota.CMsgSerializedSOCache.TypeCache.service_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6623,
  serialized_end=6685,
)

_CMSGSERIALIZEDSOCACHE_CACHE_VERSION = _descriptor.Descriptor(
  name='Version',
  full_name='dota.CMsgSerializedSOCache.Cache.Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='service', full_name='dota.CMsgSerializedSOCache.Cache.Version.service', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='dota.CMsgSerializedSOCache.Cache.Version.version', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6844,
  serialized_end=6887,
)

_CMSGSERIALIZEDSOCACHE_CACHE = _descriptor.Descriptor(
  name='Cache',
  full_name='dota.CMsgSerializedSOCache.Cache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='dota.CMsgSerializedSOCache.Cache.type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='dota.CMsgSerializedSOCache.Cache.id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versions', full_name='dota.CMsgSerializedSOCache.Cache.versions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_caches', full_name='dota.CMsgSerializedSOCache.Cache.type_caches', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSERIALIZEDSOCACHE_CACHE_VERSION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6688,
  serialized_end=6887,
)

_CMSGSERIALIZEDSOCACHE = _descriptor.Descriptor(
  name='CMsgSerializedSOCache',
  full_name='dota.CMsgSerializedSOCache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_version', full_name='dota.CMsgSerializedSOCache.file_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='caches', full_name='dota.CMsgSerializedSOCache.caches', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gc_socache_file_version', full_name='dota.CMsgSerializedSOCache.gc_socache_file_version', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSERIALIZEDSOCACHE_TYPECACHE, _CMSGSERIALIZEDSOCACHE_CACHE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6492,
  serialized_end=6887,
)


_CMSGGCTOCLIENTPOLLCONVARREQUEST = _descriptor.Descriptor(
  name='CMsgGCToClientPollConvarRequest',
  full_name='dota.CMsgGCToClientPollConvarRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='convar_name', full_name='dota.CMsgGCToClientPollConvarRequest.convar_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='poll_id', full_name='dota.CMsgGCToClientPollConvarRequest.poll_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6889,
  serialized_end=6960,
)


_CMSGGCTOCLIENTPOLLCONVARRESPONSE = _descriptor.Descriptor(
  name='CMsgGCToClientPollConvarResponse',
  full_name='dota.CMsgGCToClientPollConvarResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='poll_id', full_name='dota.CMsgGCToClientPollConvarResponse.poll_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='convar_value', full_name='dota.CMsgGCToClientPollConvarResponse.convar_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6962,
  serialized_end=7035,
)


_CGCMSGCOMPRESSEDMSGTOCLIENT = _descriptor.Descriptor(
  name='CGCMsgCompressedMsgToClient',
  full_name='dota.CGCMsgCompressedMsgToClient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg_id', full_name='dota.CGCMsgCompressedMsgToClient.msg_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compressed_msg', full_name='dota.CGCMsgCompressedMsgToClient.compressed_msg', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7037,
  serialized_end=7106,
)


_CMSGGCTOGCMASTERBROADCASTMESSAGE = _descriptor.Descriptor(
  name='CMsgGCToGCMasterBroadcastMessage',
  full_name='dota.CMsgGCToGCMasterBroadcastMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='users_per_second', full_name='dota.CMsgGCToGCMasterBroadcastMessage.users_per_second', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_to_users', full_name='dota.CMsgGCToGCMasterBroadcastMessage.send_to_users', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_to_servers', full_name='dota.CMsgGCToGCMasterBroadcastMessage.send_to_servers', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_id', full_name='dota.CMsgGCToGCMasterBroadcastMessage.msg_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_data', full_name='dota.CMsgGCToGCMasterBroadcastMessage.msg_data', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7109,
  serialized_end=7251,
)


_CMSGGCTOGCMASTERSUBSCRIBETOCACHE = _descriptor.Descriptor(
  name='CMsgGCToGCMasterSubscribeToCache',
  full_name='dota.CMsgGCToGCMasterSubscribeToCache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='soid_type', full_name='dota.CMsgGCToGCMasterSubscribeToCache.soid_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='soid_id', full_name='dota.CMsgGCToGCMasterSubscribeToCache.soid_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='dota.CMsgGCToGCMasterSubscribeToCache.account_ids', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_ids', full_name='dota.CMsgGCToGCMasterSubscribeToCache.steam_ids', index=3,
      number=4, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7253,
  serialized_end=7363,
)


_CMSGGCTOGCMASTERSUBSCRIBETOCACHERESPONSE = _descriptor.Descriptor(
  name='CMsgGCToGCMasterSubscribeToCacheResponse',
  full_name='dota.CMsgGCToGCMasterSubscribeToCacheResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7365,
  serialized_end=7407,
)


_CMSGGCTOGCMASTERSUBSCRIBETOCACHEASYNC = _descriptor.Descriptor(
  name='CMsgGCToGCMasterSubscribeToCacheAsync',
  full_name='dota.CMsgGCToGCMasterSubscribeToCacheAsync',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subscribe_msg', full_name='dota.CMsgGCToGCMasterSubscribeToCacheAsync.subscribe_msg', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7409,
  serialized_end=7511,
)


_CMSGGCTOGCMASTERUNSUBSCRIBEFROMCACHE = _descriptor.Descriptor(
  name='CMsgGCToGCMasterUnsubscribeFromCache',
  full_name='dota.CMsgGCToGCMasterUnsubscribeFromCache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='soid_type', full_name='dota.CMsgGCToGCMasterUnsubscribeFromCache.soid_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='soid_id', full_name='dota.CMsgGCToGCMasterUnsubscribeFromCache.soid_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_ids', full_name='dota.CMsgGCToGCMasterUnsubscribeFromCache.account_ids', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steam_ids', full_name='dota.CMsgGCToGCMasterUnsubscribeFromCache.steam_ids', index=3,
      number=4, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7513,
  serialized_end=7627,
)


_CMSGGCTOGCMASTERDESTROYCACHE = _descriptor.Descriptor(
  name='CMsgGCToGCMasterDestroyCache',
  full_name='dota.CMsgGCToGCMasterDestroyCache',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='soid_type', full_name='dota.CMsgGCToGCMasterDestroyCache.soid_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='soid_id', full_name='dota.CMsgGCToGCMasterDestroyCache.soid_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7629,
  serialized_end=7695,
)

_CMSGSOSINGLEOBJECT.fields_by_name['owner_soid'].message_type = _CMSGSOIDOWNER
_CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT.containing_type = _CMSGSOMULTIPLEOBJECTS
_CMSGSOMULTIPLEOBJECTS.fields_by_name['objects_modified'].message_type = _CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT
_CMSGSOMULTIPLEOBJECTS.fields_by_name['objects_added'].message_type = _CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT
_CMSGSOMULTIPLEOBJECTS.fields_by_name['objects_removed'].message_type = _CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT
_CMSGSOMULTIPLEOBJECTS.fields_by_name['owner_soid'].message_type = _CMSGSOIDOWNER
_CMSGSOCACHESUBSCRIBED_SUBSCRIBEDTYPE.containing_type = _CMSGSOCACHESUBSCRIBED
_CMSGSOCACHESUBSCRIBED.fields_by_name['objects'].message_type = _CMSGSOCACHESUBSCRIBED_SUBSCRIBEDTYPE
_CMSGSOCACHESUBSCRIBED.fields_by_name['owner_soid'].message_type = _CMSGSOIDOWNER
_CMSGSOCACHESUBSCRIBEDUPTODATE.fields_by_name['owner_soid'].message_type = _CMSGSOIDOWNER
_CMSGSOCACHEUNSUBSCRIBED.fields_by_name['owner_soid'].message_type = _CMSGSOIDOWNER
_CMSGSOCACHESUBSCRIPTIONCHECK.fields_by_name['owner_soid'].message_type = _CMSGSOIDOWNER
_CMSGSOCACHESUBSCRIPTIONREFRESH.fields_by_name['owner_soid'].message_type = _CMSGSOIDOWNER
_CGCTOGCMSGMASTERACK_PROCESS.containing_type = _CGCTOGCMSGMASTERACK
_CGCTOGCMSGMASTERACK.fields_by_name['directory'].message_type = _CGCTOGCMSGMASTERACK_PROCESS
_CGCTOGCMSGMASTERSTARTUPCOMPLETE_GCINFO.containing_type = _CGCTOGCMSGMASTERSTARTUPCOMPLETE
_CGCTOGCMSGMASTERSTARTUPCOMPLETE.fields_by_name['gc_info'].message_type = _CGCTOGCMSGMASTERSTARTUPCOMPLETE_GCINFO
_CMSGGCUPDATESUBGCSESSIONINFO_CMSGUPDATE.containing_type = _CMSGGCUPDATESUBGCSESSIONINFO
_CMSGGCUPDATESUBGCSESSIONINFO.fields_by_name['updates'].message_type = _CMSGGCUPDATESUBGCSESSIONINFO_CMSGUPDATE
_CMSGSOCACHEHAVEVERSION.fields_by_name['soid'].message_type = _CMSGSOIDOWNER
_CMSGCLIENTHELLO.fields_by_name['socache_have_versions'].message_type = _CMSGSOCACHEHAVEVERSION
_CMSGCLIENTHELLO.fields_by_name['client_launcher'].enum_type = _PARTNERACCOUNTTYPE
_CMSGCLIENTHELLO.fields_by_name['engine'].enum_type = _ESOURCEENGINE
_CMSGCLIENTWELCOME_LOCATION.containing_type = _CMSGCLIENTWELCOME
_CMSGCLIENTWELCOME.fields_by_name['outofdate_subscribed_caches'].message_type = _CMSGSOCACHESUBSCRIBED
_CMSGCLIENTWELCOME.fields_by_name['uptodate_subscribed_caches'].message_type = _CMSGSOCACHESUBSCRIPTIONCHECK
_CMSGCLIENTWELCOME.fields_by_name['location'].message_type = _CMSGCLIENTWELCOME_LOCATION
_CMSGCONNECTIONSTATUS.fields_by_name['status'].enum_type = _GCCONNECTIONSTATUS
_CMSGGCTOGCSOCACHESUBSCRIBE_CMSGHAVEVERSIONS.containing_type = _CMSGGCTOGCSOCACHESUBSCRIBE
_CMSGGCTOGCSOCACHESUBSCRIBE.fields_by_name['have_versions'].message_type = _CMSGGCTOGCSOCACHESUBSCRIBE_CMSGHAVEVERSIONS
_CMSGGCTOGCFORWARDACCOUNTDETAILS.fields_by_name['account_details'].message_type = steammessages__pb2._CGCSYSTEMMSG_GETACCOUNTDETAILS_RESPONSE
_CMSGGCTOGCLOADSESSIONSOCACHE.fields_by_name['forward_account_details'].message_type = _CMSGGCTOGCFORWARDACCOUNTDETAILS
_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_SINGLEITEMDESCRIPTION.containing_type = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST
_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_ITEMDESCRIPTIONSLANGUAGEBLOCK.fields_by_name['descriptions'].message_type = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_SINGLEITEMDESCRIPTION
_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_ITEMDESCRIPTIONSLANGUAGEBLOCK.containing_type = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST
_CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST.fields_by_name['languages'].message_type = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_ITEMDESCRIPTIONSLANGUAGEBLOCK
_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_WORKSHOPITEMPAYMENTRULE.containing_type = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST
_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_PARTNERITEMPAYMENTRULE.containing_type = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST
_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST.fields_by_name['associated_workshop_files'].message_type = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_WORKSHOPITEMPAYMENTRULE
_CWORKSHOP_SETITEMPAYMENTRULES_REQUEST.fields_by_name['partner_accounts'].message_type = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_PARTNERITEMPAYMENTRULE
_CCOMMUNITY_GETCLANANNOUNCEMENTS_RESPONSE.fields_by_name['announcements'].message_type = _CCOMMUNITY_CLANANNOUNCEMENTINFO
_CMSGSERIALIZEDSOCACHE_TYPECACHE.containing_type = _CMSGSERIALIZEDSOCACHE
_CMSGSERIALIZEDSOCACHE_CACHE_VERSION.containing_type = _CMSGSERIALIZEDSOCACHE_CACHE
_CMSGSERIALIZEDSOCACHE_CACHE.fields_by_name['versions'].message_type = _CMSGSERIALIZEDSOCACHE_CACHE_VERSION
_CMSGSERIALIZEDSOCACHE_CACHE.fields_by_name['type_caches'].message_type = _CMSGSERIALIZEDSOCACHE_TYPECACHE
_CMSGSERIALIZEDSOCACHE_CACHE.containing_type = _CMSGSERIALIZEDSOCACHE
_CMSGSERIALIZEDSOCACHE.fields_by_name['caches'].message_type = _CMSGSERIALIZEDSOCACHE_CACHE
_CMSGGCTOGCMASTERSUBSCRIBETOCACHEASYNC.fields_by_name['subscribe_msg'].message_type = _CMSGGCTOGCMASTERSUBSCRIBETOCACHE
DESCRIPTOR.message_types_by_name['CMsgSHA1Digest'] = _CMSGSHA1DIGEST
DESCRIPTOR.message_types_by_name['CMsgSOIDOwner'] = _CMSGSOIDOWNER
DESCRIPTOR.message_types_by_name['CMsgSOSingleObject'] = _CMSGSOSINGLEOBJECT
DESCRIPTOR.message_types_by_name['CMsgSOMultipleObjects'] = _CMSGSOMULTIPLEOBJECTS
DESCRIPTOR.message_types_by_name['CMsgSOCacheSubscribed'] = _CMSGSOCACHESUBSCRIBED
DESCRIPTOR.message_types_by_name['CMsgSOCacheSubscribedUpToDate'] = _CMSGSOCACHESUBSCRIBEDUPTODATE
DESCRIPTOR.message_types_by_name['CMsgSOCacheUnsubscribed'] = _CMSGSOCACHEUNSUBSCRIBED
DESCRIPTOR.message_types_by_name['CMsgSOCacheSubscriptionCheck'] = _CMSGSOCACHESUBSCRIPTIONCHECK
DESCRIPTOR.message_types_by_name['CMsgSOCacheSubscriptionRefresh'] = _CMSGSOCACHESUBSCRIPTIONREFRESH
DESCRIPTOR.message_types_by_name['CMsgSOCacheVersion'] = _CMSGSOCACHEVERSION
DESCRIPTOR.message_types_by_name['CMsgGCMultiplexMessage'] = _CMSGGCMULTIPLEXMESSAGE
DESCRIPTOR.message_types_by_name['CMsgGCToGCSubGCStarting'] = _CMSGGCTOGCSUBGCSTARTING
DESCRIPTOR.message_types_by_name['CGCToGCMsgMasterAck'] = _CGCTOGCMSGMASTERACK
DESCRIPTOR.message_types_by_name['CGCToGCMsgMasterAck_Response'] = _CGCTOGCMSGMASTERACK_RESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCUniverseStartup'] = _CMSGGCTOGCUNIVERSESTARTUP
DESCRIPTOR.message_types_by_name['CMsgGCToGCUniverseStartupResponse'] = _CMSGGCTOGCUNIVERSESTARTUPRESPONSE
DESCRIPTOR.message_types_by_name['CGCToGCMsgMasterStartupComplete'] = _CGCTOGCMSGMASTERSTARTUPCOMPLETE
DESCRIPTOR.message_types_by_name['CGCToGCMsgRouted'] = _CGCTOGCMSGROUTED
DESCRIPTOR.message_types_by_name['CGCToGCMsgRoutedReply'] = _CGCTOGCMSGROUTEDREPLY
DESCRIPTOR.message_types_by_name['CMsgGCUpdateSubGCSessionInfo'] = _CMSGGCUPDATESUBGCSESSIONINFO
DESCRIPTOR.message_types_by_name['CMsgGCRequestSubGCSessionInfo'] = _CMSGGCREQUESTSUBGCSESSIONINFO
DESCRIPTOR.message_types_by_name['CMsgGCRequestSubGCSessionInfoResponse'] = _CMSGGCREQUESTSUBGCSESSIONINFORESPONSE
DESCRIPTOR.message_types_by_name['CMsgSOCacheHaveVersion'] = _CMSGSOCACHEHAVEVERSION
DESCRIPTOR.message_types_by_name['CMsgClientHello'] = _CMSGCLIENTHELLO
DESCRIPTOR.message_types_by_name['CMsgClientWelcome'] = _CMSGCLIENTWELCOME
DESCRIPTOR.message_types_by_name['CMsgConnectionStatus'] = _CMSGCONNECTIONSTATUS
DESCRIPTOR.message_types_by_name['CMsgGCToGCSOCacheSubscribe'] = _CMSGGCTOGCSOCACHESUBSCRIBE
DESCRIPTOR.message_types_by_name['CMsgGCToGCSOCacheUnsubscribe'] = _CMSGGCTOGCSOCACHEUNSUBSCRIBE
DESCRIPTOR.message_types_by_name['CMsgGCClientPing'] = _CMSGGCCLIENTPING
DESCRIPTOR.message_types_by_name['CMsgGCToGCForwardAccountDetails'] = _CMSGGCTOGCFORWARDACCOUNTDETAILS
DESCRIPTOR.message_types_by_name['CMsgGCToGCLoadSessionSOCache'] = _CMSGGCTOGCLOADSESSIONSOCACHE
DESCRIPTOR.message_types_by_name['CMsgGCToGCLoadSessionSOCacheResponse'] = _CMSGGCTOGCLOADSESSIONSOCACHERESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCUpdateSessionStats'] = _CMSGGCTOGCUPDATESESSIONSTATS
DESCRIPTOR.message_types_by_name['CMsgGCToClientRequestDropped'] = _CMSGGCTOCLIENTREQUESTDROPPED
DESCRIPTOR.message_types_by_name['CWorkshop_PopulateItemDescriptions_Request'] = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST
DESCRIPTOR.message_types_by_name['CWorkshop_GetContributors_Request'] = _CWORKSHOP_GETCONTRIBUTORS_REQUEST
DESCRIPTOR.message_types_by_name['CWorkshop_GetContributors_Response'] = _CWORKSHOP_GETCONTRIBUTORS_RESPONSE
DESCRIPTOR.message_types_by_name['CWorkshop_SetItemPaymentRules_Request'] = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST
DESCRIPTOR.message_types_by_name['CWorkshop_SetItemPaymentRules_Response'] = _CWORKSHOP_SETITEMPAYMENTRULES_RESPONSE
DESCRIPTOR.message_types_by_name['CCommunity_ClanAnnouncementInfo'] = _CCOMMUNITY_CLANANNOUNCEMENTINFO
DESCRIPTOR.message_types_by_name['CCommunity_GetClanAnnouncements_Request'] = _CCOMMUNITY_GETCLANANNOUNCEMENTS_REQUEST
DESCRIPTOR.message_types_by_name['CCommunity_GetClanAnnouncements_Response'] = _CCOMMUNITY_GETCLANANNOUNCEMENTS_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_PostGameDataFrame_Request'] = _CBROADCAST_POSTGAMEDATAFRAME_REQUEST
DESCRIPTOR.message_types_by_name['CMsgSerializedSOCache'] = _CMSGSERIALIZEDSOCACHE
DESCRIPTOR.message_types_by_name['CMsgGCToClientPollConvarRequest'] = _CMSGGCTOCLIENTPOLLCONVARREQUEST
DESCRIPTOR.message_types_by_name['CMsgGCToClientPollConvarResponse'] = _CMSGGCTOCLIENTPOLLCONVARRESPONSE
DESCRIPTOR.message_types_by_name['CGCMsgCompressedMsgToClient'] = _CGCMSGCOMPRESSEDMSGTOCLIENT
DESCRIPTOR.message_types_by_name['CMsgGCToGCMasterBroadcastMessage'] = _CMSGGCTOGCMASTERBROADCASTMESSAGE
DESCRIPTOR.message_types_by_name['CMsgGCToGCMasterSubscribeToCache'] = _CMSGGCTOGCMASTERSUBSCRIBETOCACHE
DESCRIPTOR.message_types_by_name['CMsgGCToGCMasterSubscribeToCacheResponse'] = _CMSGGCTOGCMASTERSUBSCRIBETOCACHERESPONSE
DESCRIPTOR.message_types_by_name['CMsgGCToGCMasterSubscribeToCacheAsync'] = _CMSGGCTOGCMASTERSUBSCRIBETOCACHEASYNC
DESCRIPTOR.message_types_by_name['CMsgGCToGCMasterUnsubscribeFromCache'] = _CMSGGCTOGCMASTERUNSUBSCRIBEFROMCACHE
DESCRIPTOR.message_types_by_name['CMsgGCToGCMasterDestroyCache'] = _CMSGGCTOGCMASTERDESTROYCACHE
DESCRIPTOR.enum_types_by_name['ESourceEngine'] = _ESOURCEENGINE
DESCRIPTOR.enum_types_by_name['PartnerAccountType'] = _PARTNERACCOUNTTYPE
DESCRIPTOR.enum_types_by_name['GCConnectionStatus'] = _GCCONNECTIONSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgSHA1Digest = _reflection.GeneratedProtocolMessageType('CMsgSHA1Digest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSHA1DIGEST,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSHA1Digest)
  ))
_sym_db.RegisterMessage(CMsgSHA1Digest)

CMsgSOIDOwner = _reflection.GeneratedProtocolMessageType('CMsgSOIDOwner', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOIDOWNER,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSOIDOwner)
  ))
_sym_db.RegisterMessage(CMsgSOIDOwner)

CMsgSOSingleObject = _reflection.GeneratedProtocolMessageType('CMsgSOSingleObject', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOSINGLEOBJECT,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSOSingleObject)
  ))
_sym_db.RegisterMessage(CMsgSOSingleObject)

CMsgSOMultipleObjects = _reflection.GeneratedProtocolMessageType('CMsgSOMultipleObjects', (_message.Message,), dict(

  SingleObject = _reflection.GeneratedProtocolMessageType('SingleObject', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT,
    __module__ = 'gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgSOMultipleObjects.SingleObject)
    ))
  ,
  DESCRIPTOR = _CMSGSOMULTIPLEOBJECTS,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSOMultipleObjects)
  ))
_sym_db.RegisterMessage(CMsgSOMultipleObjects)
_sym_db.RegisterMessage(CMsgSOMultipleObjects.SingleObject)

CMsgSOCacheSubscribed = _reflection.GeneratedProtocolMessageType('CMsgSOCacheSubscribed', (_message.Message,), dict(

  SubscribedType = _reflection.GeneratedProtocolMessageType('SubscribedType', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSOCACHESUBSCRIBED_SUBSCRIBEDTYPE,
    __module__ = 'gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgSOCacheSubscribed.SubscribedType)
    ))
  ,
  DESCRIPTOR = _CMSGSOCACHESUBSCRIBED,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSOCacheSubscribed)
  ))
_sym_db.RegisterMessage(CMsgSOCacheSubscribed)
_sym_db.RegisterMessage(CMsgSOCacheSubscribed.SubscribedType)

CMsgSOCacheSubscribedUpToDate = _reflection.GeneratedProtocolMessageType('CMsgSOCacheSubscribedUpToDate', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOCACHESUBSCRIBEDUPTODATE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSOCacheSubscribedUpToDate)
  ))
_sym_db.RegisterMessage(CMsgSOCacheSubscribedUpToDate)

CMsgSOCacheUnsubscribed = _reflection.GeneratedProtocolMessageType('CMsgSOCacheUnsubscribed', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOCACHEUNSUBSCRIBED,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSOCacheUnsubscribed)
  ))
_sym_db.RegisterMessage(CMsgSOCacheUnsubscribed)

CMsgSOCacheSubscriptionCheck = _reflection.GeneratedProtocolMessageType('CMsgSOCacheSubscriptionCheck', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOCACHESUBSCRIPTIONCHECK,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSOCacheSubscriptionCheck)
  ))
_sym_db.RegisterMessage(CMsgSOCacheSubscriptionCheck)

CMsgSOCacheSubscriptionRefresh = _reflection.GeneratedProtocolMessageType('CMsgSOCacheSubscriptionRefresh', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOCACHESUBSCRIPTIONREFRESH,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSOCacheSubscriptionRefresh)
  ))
_sym_db.RegisterMessage(CMsgSOCacheSubscriptionRefresh)

CMsgSOCacheVersion = _reflection.GeneratedProtocolMessageType('CMsgSOCacheVersion', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOCACHEVERSION,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSOCacheVersion)
  ))
_sym_db.RegisterMessage(CMsgSOCacheVersion)

CMsgGCMultiplexMessage = _reflection.GeneratedProtocolMessageType('CMsgGCMultiplexMessage', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCMULTIPLEXMESSAGE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCMultiplexMessage)
  ))
_sym_db.RegisterMessage(CMsgGCMultiplexMessage)

CMsgGCToGCSubGCStarting = _reflection.GeneratedProtocolMessageType('CMsgGCToGCSubGCStarting', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCSUBGCSTARTING,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCSubGCStarting)
  ))
_sym_db.RegisterMessage(CMsgGCToGCSubGCStarting)

CGCToGCMsgMasterAck = _reflection.GeneratedProtocolMessageType('CGCToGCMsgMasterAck', (_message.Message,), dict(

  Process = _reflection.GeneratedProtocolMessageType('Process', (_message.Message,), dict(
    DESCRIPTOR = _CGCTOGCMSGMASTERACK_PROCESS,
    __module__ = 'gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:dota.CGCToGCMsgMasterAck.Process)
    ))
  ,
  DESCRIPTOR = _CGCTOGCMSGMASTERACK,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CGCToGCMsgMasterAck)
  ))
_sym_db.RegisterMessage(CGCToGCMsgMasterAck)
_sym_db.RegisterMessage(CGCToGCMsgMasterAck.Process)

CGCToGCMsgMasterAck_Response = _reflection.GeneratedProtocolMessageType('CGCToGCMsgMasterAck_Response', (_message.Message,), dict(
  DESCRIPTOR = _CGCTOGCMSGMASTERACK_RESPONSE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CGCToGCMsgMasterAck_Response)
  ))
_sym_db.RegisterMessage(CGCToGCMsgMasterAck_Response)

CMsgGCToGCUniverseStartup = _reflection.GeneratedProtocolMessageType('CMsgGCToGCUniverseStartup', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCUNIVERSESTARTUP,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCUniverseStartup)
  ))
_sym_db.RegisterMessage(CMsgGCToGCUniverseStartup)

CMsgGCToGCUniverseStartupResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToGCUniverseStartupResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCUNIVERSESTARTUPRESPONSE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCUniverseStartupResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToGCUniverseStartupResponse)

CGCToGCMsgMasterStartupComplete = _reflection.GeneratedProtocolMessageType('CGCToGCMsgMasterStartupComplete', (_message.Message,), dict(

  GCInfo = _reflection.GeneratedProtocolMessageType('GCInfo', (_message.Message,), dict(
    DESCRIPTOR = _CGCTOGCMSGMASTERSTARTUPCOMPLETE_GCINFO,
    __module__ = 'gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:dota.CGCToGCMsgMasterStartupComplete.GCInfo)
    ))
  ,
  DESCRIPTOR = _CGCTOGCMSGMASTERSTARTUPCOMPLETE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CGCToGCMsgMasterStartupComplete)
  ))
_sym_db.RegisterMessage(CGCToGCMsgMasterStartupComplete)
_sym_db.RegisterMessage(CGCToGCMsgMasterStartupComplete.GCInfo)

CGCToGCMsgRouted = _reflection.GeneratedProtocolMessageType('CGCToGCMsgRouted', (_message.Message,), dict(
  DESCRIPTOR = _CGCTOGCMSGROUTED,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CGCToGCMsgRouted)
  ))
_sym_db.RegisterMessage(CGCToGCMsgRouted)

CGCToGCMsgRoutedReply = _reflection.GeneratedProtocolMessageType('CGCToGCMsgRoutedReply', (_message.Message,), dict(
  DESCRIPTOR = _CGCTOGCMSGROUTEDREPLY,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CGCToGCMsgRoutedReply)
  ))
_sym_db.RegisterMessage(CGCToGCMsgRoutedReply)

CMsgGCUpdateSubGCSessionInfo = _reflection.GeneratedProtocolMessageType('CMsgGCUpdateSubGCSessionInfo', (_message.Message,), dict(

  CMsgUpdate = _reflection.GeneratedProtocolMessageType('CMsgUpdate', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCUPDATESUBGCSESSIONINFO_CMSGUPDATE,
    __module__ = 'gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCUpdateSubGCSessionInfo.CMsgUpdate)
    ))
  ,
  DESCRIPTOR = _CMSGGCUPDATESUBGCSESSIONINFO,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCUpdateSubGCSessionInfo)
  ))
_sym_db.RegisterMessage(CMsgGCUpdateSubGCSessionInfo)
_sym_db.RegisterMessage(CMsgGCUpdateSubGCSessionInfo.CMsgUpdate)

CMsgGCRequestSubGCSessionInfo = _reflection.GeneratedProtocolMessageType('CMsgGCRequestSubGCSessionInfo', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCREQUESTSUBGCSESSIONINFO,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCRequestSubGCSessionInfo)
  ))
_sym_db.RegisterMessage(CMsgGCRequestSubGCSessionInfo)

CMsgGCRequestSubGCSessionInfoResponse = _reflection.GeneratedProtocolMessageType('CMsgGCRequestSubGCSessionInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCREQUESTSUBGCSESSIONINFORESPONSE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCRequestSubGCSessionInfoResponse)
  ))
_sym_db.RegisterMessage(CMsgGCRequestSubGCSessionInfoResponse)

CMsgSOCacheHaveVersion = _reflection.GeneratedProtocolMessageType('CMsgSOCacheHaveVersion', (_message.Message,), dict(
  DESCRIPTOR = _CMSGSOCACHEHAVEVERSION,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSOCacheHaveVersion)
  ))
_sym_db.RegisterMessage(CMsgSOCacheHaveVersion)

CMsgClientHello = _reflection.GeneratedProtocolMessageType('CMsgClientHello', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCLIENTHELLO,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientHello)
  ))
_sym_db.RegisterMessage(CMsgClientHello)

CMsgClientWelcome = _reflection.GeneratedProtocolMessageType('CMsgClientWelcome', (_message.Message,), dict(

  Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), dict(
    DESCRIPTOR = _CMSGCLIENTWELCOME_LOCATION,
    __module__ = 'gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgClientWelcome.Location)
    ))
  ,
  DESCRIPTOR = _CMSGCLIENTWELCOME,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgClientWelcome)
  ))
_sym_db.RegisterMessage(CMsgClientWelcome)
_sym_db.RegisterMessage(CMsgClientWelcome.Location)

CMsgConnectionStatus = _reflection.GeneratedProtocolMessageType('CMsgConnectionStatus', (_message.Message,), dict(
  DESCRIPTOR = _CMSGCONNECTIONSTATUS,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgConnectionStatus)
  ))
_sym_db.RegisterMessage(CMsgConnectionStatus)

CMsgGCToGCSOCacheSubscribe = _reflection.GeneratedProtocolMessageType('CMsgGCToGCSOCacheSubscribe', (_message.Message,), dict(

  CMsgHaveVersions = _reflection.GeneratedProtocolMessageType('CMsgHaveVersions', (_message.Message,), dict(
    DESCRIPTOR = _CMSGGCTOGCSOCACHESUBSCRIBE_CMSGHAVEVERSIONS,
    __module__ = 'gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCSOCacheSubscribe.CMsgHaveVersions)
    ))
  ,
  DESCRIPTOR = _CMSGGCTOGCSOCACHESUBSCRIBE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCSOCacheSubscribe)
  ))
_sym_db.RegisterMessage(CMsgGCToGCSOCacheSubscribe)
_sym_db.RegisterMessage(CMsgGCToGCSOCacheSubscribe.CMsgHaveVersions)

CMsgGCToGCSOCacheUnsubscribe = _reflection.GeneratedProtocolMessageType('CMsgGCToGCSOCacheUnsubscribe', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCSOCACHEUNSUBSCRIBE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCSOCacheUnsubscribe)
  ))
_sym_db.RegisterMessage(CMsgGCToGCSOCacheUnsubscribe)

CMsgGCClientPing = _reflection.GeneratedProtocolMessageType('CMsgGCClientPing', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCCLIENTPING,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCClientPing)
  ))
_sym_db.RegisterMessage(CMsgGCClientPing)

CMsgGCToGCForwardAccountDetails = _reflection.GeneratedProtocolMessageType('CMsgGCToGCForwardAccountDetails', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCFORWARDACCOUNTDETAILS,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCForwardAccountDetails)
  ))
_sym_db.RegisterMessage(CMsgGCToGCForwardAccountDetails)

CMsgGCToGCLoadSessionSOCache = _reflection.GeneratedProtocolMessageType('CMsgGCToGCLoadSessionSOCache', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCLOADSESSIONSOCACHE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCLoadSessionSOCache)
  ))
_sym_db.RegisterMessage(CMsgGCToGCLoadSessionSOCache)

CMsgGCToGCLoadSessionSOCacheResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToGCLoadSessionSOCacheResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCLOADSESSIONSOCACHERESPONSE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCLoadSessionSOCacheResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToGCLoadSessionSOCacheResponse)

CMsgGCToGCUpdateSessionStats = _reflection.GeneratedProtocolMessageType('CMsgGCToGCUpdateSessionStats', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCUPDATESESSIONSTATS,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCUpdateSessionStats)
  ))
_sym_db.RegisterMessage(CMsgGCToGCUpdateSessionStats)

CMsgGCToClientRequestDropped = _reflection.GeneratedProtocolMessageType('CMsgGCToClientRequestDropped', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTREQUESTDROPPED,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientRequestDropped)
  ))
_sym_db.RegisterMessage(CMsgGCToClientRequestDropped)

CWorkshop_PopulateItemDescriptions_Request = _reflection.GeneratedProtocolMessageType('CWorkshop_PopulateItemDescriptions_Request', (_message.Message,), dict(

  SingleItemDescription = _reflection.GeneratedProtocolMessageType('SingleItemDescription', (_message.Message,), dict(
    DESCRIPTOR = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_SINGLEITEMDESCRIPTION,
    __module__ = 'gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:dota.CWorkshop_PopulateItemDescriptions_Request.SingleItemDescription)
    ))
  ,

  ItemDescriptionsLanguageBlock = _reflection.GeneratedProtocolMessageType('ItemDescriptionsLanguageBlock', (_message.Message,), dict(
    DESCRIPTOR = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST_ITEMDESCRIPTIONSLANGUAGEBLOCK,
    __module__ = 'gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:dota.CWorkshop_PopulateItemDescriptions_Request.ItemDescriptionsLanguageBlock)
    ))
  ,
  DESCRIPTOR = _CWORKSHOP_POPULATEITEMDESCRIPTIONS_REQUEST,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CWorkshop_PopulateItemDescriptions_Request)
  ))
_sym_db.RegisterMessage(CWorkshop_PopulateItemDescriptions_Request)
_sym_db.RegisterMessage(CWorkshop_PopulateItemDescriptions_Request.SingleItemDescription)
_sym_db.RegisterMessage(CWorkshop_PopulateItemDescriptions_Request.ItemDescriptionsLanguageBlock)

CWorkshop_GetContributors_Request = _reflection.GeneratedProtocolMessageType('CWorkshop_GetContributors_Request', (_message.Message,), dict(
  DESCRIPTOR = _CWORKSHOP_GETCONTRIBUTORS_REQUEST,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CWorkshop_GetContributors_Request)
  ))
_sym_db.RegisterMessage(CWorkshop_GetContributors_Request)

CWorkshop_GetContributors_Response = _reflection.GeneratedProtocolMessageType('CWorkshop_GetContributors_Response', (_message.Message,), dict(
  DESCRIPTOR = _CWORKSHOP_GETCONTRIBUTORS_RESPONSE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CWorkshop_GetContributors_Response)
  ))
_sym_db.RegisterMessage(CWorkshop_GetContributors_Response)

CWorkshop_SetItemPaymentRules_Request = _reflection.GeneratedProtocolMessageType('CWorkshop_SetItemPaymentRules_Request', (_message.Message,), dict(

  WorkshopItemPaymentRule = _reflection.GeneratedProtocolMessageType('WorkshopItemPaymentRule', (_message.Message,), dict(
    DESCRIPTOR = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_WORKSHOPITEMPAYMENTRULE,
    __module__ = 'gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:dota.CWorkshop_SetItemPaymentRules_Request.WorkshopItemPaymentRule)
    ))
  ,

  PartnerItemPaymentRule = _reflection.GeneratedProtocolMessageType('PartnerItemPaymentRule', (_message.Message,), dict(
    DESCRIPTOR = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST_PARTNERITEMPAYMENTRULE,
    __module__ = 'gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:dota.CWorkshop_SetItemPaymentRules_Request.PartnerItemPaymentRule)
    ))
  ,
  DESCRIPTOR = _CWORKSHOP_SETITEMPAYMENTRULES_REQUEST,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CWorkshop_SetItemPaymentRules_Request)
  ))
_sym_db.RegisterMessage(CWorkshop_SetItemPaymentRules_Request)
_sym_db.RegisterMessage(CWorkshop_SetItemPaymentRules_Request.WorkshopItemPaymentRule)
_sym_db.RegisterMessage(CWorkshop_SetItemPaymentRules_Request.PartnerItemPaymentRule)

CWorkshop_SetItemPaymentRules_Response = _reflection.GeneratedProtocolMessageType('CWorkshop_SetItemPaymentRules_Response', (_message.Message,), dict(
  DESCRIPTOR = _CWORKSHOP_SETITEMPAYMENTRULES_RESPONSE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CWorkshop_SetItemPaymentRules_Response)
  ))
_sym_db.RegisterMessage(CWorkshop_SetItemPaymentRules_Response)

CCommunity_ClanAnnouncementInfo = _reflection.GeneratedProtocolMessageType('CCommunity_ClanAnnouncementInfo', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_CLANANNOUNCEMENTINFO,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CCommunity_ClanAnnouncementInfo)
  ))
_sym_db.RegisterMessage(CCommunity_ClanAnnouncementInfo)

CCommunity_GetClanAnnouncements_Request = _reflection.GeneratedProtocolMessageType('CCommunity_GetClanAnnouncements_Request', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETCLANANNOUNCEMENTS_REQUEST,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CCommunity_GetClanAnnouncements_Request)
  ))
_sym_db.RegisterMessage(CCommunity_GetClanAnnouncements_Request)

CCommunity_GetClanAnnouncements_Response = _reflection.GeneratedProtocolMessageType('CCommunity_GetClanAnnouncements_Response', (_message.Message,), dict(
  DESCRIPTOR = _CCOMMUNITY_GETCLANANNOUNCEMENTS_RESPONSE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CCommunity_GetClanAnnouncements_Response)
  ))
_sym_db.RegisterMessage(CCommunity_GetClanAnnouncements_Response)

CBroadcast_PostGameDataFrame_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_PostGameDataFrame_Request', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_POSTGAMEDATAFRAME_REQUEST,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CBroadcast_PostGameDataFrame_Request)
  ))
_sym_db.RegisterMessage(CBroadcast_PostGameDataFrame_Request)

CMsgSerializedSOCache = _reflection.GeneratedProtocolMessageType('CMsgSerializedSOCache', (_message.Message,), dict(

  TypeCache = _reflection.GeneratedProtocolMessageType('TypeCache', (_message.Message,), dict(
    DESCRIPTOR = _CMSGSERIALIZEDSOCACHE_TYPECACHE,
    __module__ = 'gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgSerializedSOCache.TypeCache)
    ))
  ,

  Cache = _reflection.GeneratedProtocolMessageType('Cache', (_message.Message,), dict(

    Version = _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), dict(
      DESCRIPTOR = _CMSGSERIALIZEDSOCACHE_CACHE_VERSION,
      __module__ = 'gcsdk_gcmessages_pb2'
      # @@protoc_insertion_point(class_scope:dota.CMsgSerializedSOCache.Cache.Version)
      ))
    ,
    DESCRIPTOR = _CMSGSERIALIZEDSOCACHE_CACHE,
    __module__ = 'gcsdk_gcmessages_pb2'
    # @@protoc_insertion_point(class_scope:dota.CMsgSerializedSOCache.Cache)
    ))
  ,
  DESCRIPTOR = _CMSGSERIALIZEDSOCACHE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgSerializedSOCache)
  ))
_sym_db.RegisterMessage(CMsgSerializedSOCache)
_sym_db.RegisterMessage(CMsgSerializedSOCache.TypeCache)
_sym_db.RegisterMessage(CMsgSerializedSOCache.Cache)
_sym_db.RegisterMessage(CMsgSerializedSOCache.Cache.Version)

CMsgGCToClientPollConvarRequest = _reflection.GeneratedProtocolMessageType('CMsgGCToClientPollConvarRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTPOLLCONVARREQUEST,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientPollConvarRequest)
  ))
_sym_db.RegisterMessage(CMsgGCToClientPollConvarRequest)

CMsgGCToClientPollConvarResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToClientPollConvarResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOCLIENTPOLLCONVARRESPONSE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToClientPollConvarResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToClientPollConvarResponse)

CGCMsgCompressedMsgToClient = _reflection.GeneratedProtocolMessageType('CGCMsgCompressedMsgToClient', (_message.Message,), dict(
  DESCRIPTOR = _CGCMSGCOMPRESSEDMSGTOCLIENT,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CGCMsgCompressedMsgToClient)
  ))
_sym_db.RegisterMessage(CGCMsgCompressedMsgToClient)

CMsgGCToGCMasterBroadcastMessage = _reflection.GeneratedProtocolMessageType('CMsgGCToGCMasterBroadcastMessage', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCMASTERBROADCASTMESSAGE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCMasterBroadcastMessage)
  ))
_sym_db.RegisterMessage(CMsgGCToGCMasterBroadcastMessage)

CMsgGCToGCMasterSubscribeToCache = _reflection.GeneratedProtocolMessageType('CMsgGCToGCMasterSubscribeToCache', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCMASTERSUBSCRIBETOCACHE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCMasterSubscribeToCache)
  ))
_sym_db.RegisterMessage(CMsgGCToGCMasterSubscribeToCache)

CMsgGCToGCMasterSubscribeToCacheResponse = _reflection.GeneratedProtocolMessageType('CMsgGCToGCMasterSubscribeToCacheResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCMASTERSUBSCRIBETOCACHERESPONSE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCMasterSubscribeToCacheResponse)
  ))
_sym_db.RegisterMessage(CMsgGCToGCMasterSubscribeToCacheResponse)

CMsgGCToGCMasterSubscribeToCacheAsync = _reflection.GeneratedProtocolMessageType('CMsgGCToGCMasterSubscribeToCacheAsync', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCMASTERSUBSCRIBETOCACHEASYNC,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCMasterSubscribeToCacheAsync)
  ))
_sym_db.RegisterMessage(CMsgGCToGCMasterSubscribeToCacheAsync)

CMsgGCToGCMasterUnsubscribeFromCache = _reflection.GeneratedProtocolMessageType('CMsgGCToGCMasterUnsubscribeFromCache', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCMASTERUNSUBSCRIBEFROMCACHE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCMasterUnsubscribeFromCache)
  ))
_sym_db.RegisterMessage(CMsgGCToGCMasterUnsubscribeFromCache)

CMsgGCToGCMasterDestroyCache = _reflection.GeneratedProtocolMessageType('CMsgGCToGCMasterDestroyCache', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGCTOGCMASTERDESTROYCACHE,
  __module__ = 'gcsdk_gcmessages_pb2'
  # @@protoc_insertion_point(class_scope:dota.CMsgGCToGCMasterDestroyCache)
  ))
_sym_db.RegisterMessage(CMsgGCToGCMasterDestroyCache)


DESCRIPTOR._options = None
_CMSGSOMULTIPLEOBJECTS_SINGLEOBJECT._options = None
# @@protoc_insertion_point(module_scope)
